@@ -10,6 +10,8 @@ from plumbum.cli import Application, ExistingFile, SwitchAttr
 from plumbum.colors import blue, green, magenta, yellow
 from rich import inspect as _rich_inspect
 from rich.console import Console as RichConsole
+from ruamel.yaml.parser import ParserError as YAMLParserError
+from ruamel.yaml.scanner import ScannerError as YAMLScannerError
 
 from . import __version__
 from .dumpers import (
@@ -27,7 +29,12 @@ def inspect_exception(exc: Exception):
     Args:
         exc: Any ``Exception``. After printing, it is swallowed, not raised.
     """
+    if isinstance(exc, (YAMLParserError, YAMLScannerError)):
+        print("This YAML couldn't be parsed", exc, sep='\n', file=sys.stderr)
+        return
+
     _rich_inspect(exc, console=RICH)
+
     try:
         items = exc.get_codicil()
     except AttributeError:
